#
# spec file for package anthy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     xemacs

Name:           anthy
Version:        9100h
Release:        42.6
Summary:        Kana-Kanji Conversion Engine
# Summary(ja): 仮名漢字変換エンジン
# Anthy(旧称Ancy)
#
# PC-Unix用の仮名漢字変換エンジンとしては Canna、 FreeWnn等が有名ですが、
# いずれも1990年前後の国産Unixワークステーションのために開発され、 フリー
# なものの開発はほぼ停止している状態です。 Hekeプロジェクトでは新たな変
# 換エンジンを辞書を除いてフルスクラッチで 開発を行っています。
#
# 著者：
# ------
#     田畑 悠介 <yusuke@kmc.kyoto-u.ac.jp>
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/I18n/Japanese
URL:            https://osdn.jp/projects/anthy/
Source0:        anthy-%{version}.tar.bz2
Source1:        suse-start-anthy.el
Source2:        baselibs.conf
Patch2:         anthy-last-command-char-xemacs.patch
Patch3:         bugzilla-224463-comparison-with-string-literal.patch
# PATCH-FIX-OPENSUSE anthy-use-last-command-event.diff bnc#849211 tiwai@suse.de
Patch4:         anthy-use-last-command-event.diff
Patch5:         bugzilla-1175274-emacs-27.1.patch
Patch6:         anthy-set-face-underline-p.patch
BuildRequires:  emacs-x11
BuildRequires:  fdupes
BuildRequires:  libtool
%if %{with xemacs}
BuildRequires:  xemacs
%endif

%description
Anthy is a package for an input method editor backend for Unix-like
systems for the Japanese language. It can convert Hiragana to Kanji
as per the language rules. As a preconversion stage, Latin characters
(Romaji) can be used to input Hiragana. Anthy is commonly used with
an input method framework such as ibus, fcitx or SCIM.

%package -n libanthy0
Summary:        Kana–Kanji conversion engine
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n libanthy0
A Kana–Kanji conversion engine.

%package devel
Summary:        Header files for the Anthy Kana–Kanji conversion engine
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libanthy0 = %{version}
# Summary(ja): Anthy のヘッダファイル及びライブラリです。
# %description devel -l ja
# Anthy のヘッダファイル及びライブラリです。

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require libanthy.

%prep
%autosetup -p1

%build
autoreconf --force --install
CFLAGS="%{optflags} -fno-strict-aliasing" \
CXXFLAGS="%{optflags} -fno-strict-aliasing" \
%configure --disable-static
%make_build

%check
cd test
./anthy --all

%install
%make_install
install -m 644 %{_sourcedir}/suse-start-anthy.el %{buildroot}/%{_datadir}/emacs/site-lisp/
%if %{with xemacs}
# compile the XEmacs versions of the emacs-lisp files and install them:
pushd src-util
    rm -f *.elc
    # make EMACS=xemacs
    EMACS=xemacs ../elisp-comp *.el
    mkdir -p %{buildroot}%{_datadir}/xemacs/site-packages/lisp/anthy
    install -m 644 *.el *.elc %{buildroot}%{_datadir}/xemacs/site-packages/lisp/anthy
popd
%endif
%fdupes %{buildroot}%{_datadir}
find %{buildroot} -type f -name "*.la" -delete -print
# remove unneeded Makefiles for documents
rm -f doc/Makefile.*

%post   -n libanthy0 -p /sbin/ldconfig
%postun -n libanthy0 -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog DIARY NEWS README doc
%license COPYING
%config %{_sysconfdir}/anthy-conf
%dir %{_datadir}/anthy/
%{_datadir}/anthy/*
%{_bindir}/*
%{_datadir}/emacs/site-lisp/*
%if %{with xemacs}
%{_datadir}/xemacs/*
%endif

%files -n libanthy0
%{_libdir}/*.so.*

%files devel
%dir %{_includedir}/anthy/
%{_includedir}/anthy/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/anthy.pc

%changelog
* Mon Aug 21 2023 Marguerite Su <i@marguerite.su>
- add anthy-set-face-underline-p.patch
  * set-face-underline-p is an alias for set-face-underline
    and was dreprecated since emacs 24.3
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
- Switch to %%autosetup (rediff bugzilla-1175274-emacs-27.1.patch
  as p1)
* Wed Sep 30 2020 Dr. Werner Fink <werner@suse.de>
- Use build condition to enable or disable Xemacs support (jsc#SLE-12100)
* Wed Sep 30 2020 Dr. Werner Fink <werner@suse.de>
- Use build condition to enable or disable Xemacs support (jsc#SLE-11658)
* Tue Sep 29 2020 Dr. Werner Fink <werner@suse.de>
- Do not use Xemacs on SLE products (jsc#SLE-12100)
* Tue Sep 29 2020 Dr. Werner Fink <werner@suse.de>
- Do not use Xemacs on SLE products (jsc#SLE-11658)
* Tue Sep 15 2020 Cliff Zhao <qzhao@suse.com>
- Update anthy.spec: Drop the is_opensuse macro to eliminate the
  difference between SLE-15 and openSUSE-Leap (jsc#SLE-11658).
* Tue Aug 18 2020 Dr. Werner Fink <werner@suse.de>
- Add patch bugzilla-1175274-emacs-27.1.patch
  There is no (process-kill-without-query) anymore, use
  (set-process-query-on-exit-flag) instead (boo#1175274).
* Thu Jun 13 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Fix baselibs.conf: the library was split out as libanthy0 with
  the last change.
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic that is useless in the face of --disable-static.
- Drop pre-openSUSE-12.3 parts from the build recipe.
- Implement the shared library packaging policy.
- Replace description because canna/freewnn seem comparatively
  active in OBS's M17N project.
* Sat Sep  1 2018 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file with spec-cleaner
- Don't install INSTALL file
- Use %%bcond_with{out}
* Fri Aug 31 2018 qzhao@suse.com
- Update anthy.spec: Divide openSUSE build with emacs function and
  SLE doesn't need it.
* Thu Feb  8 2018 msuchanek@suse.com
- Drop build-time requirement on X11. It does not seem to be used for anything.
* Tue Sep 22 2015 ftake@geeko.jp
- Stop providing locale(ja)
  + Most of ja locale users do not need this anymore
- Change the upstream URL
- Clean up the spec file
* Fri May 30 2014 jengelh@inai.de
- Drop unused build-time requirements on libpng, libgif, libtiff,
  krb5, openldap2
* Wed Nov  6 2013 tiwai@suse.de
- Fix breakage on GNU Emacs on openSUSE 13.1 (bnc#849211)
- Added patch: anthy-use-last-command-event.diff
* Fri Jul 12 2013 tiwai@suse.de
- work around the build error with xemacs 21.5.33
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Sun Jun  3 2012 i@marguerite.su
- fix sles builds.
* Sun Dec 11 2011 meissner@suse.de
- does not need openldap2 direct dependency, libraries are enough
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Dec 17 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Thu Jun  4 2009 tiwai@suse.de
- updated to anthy-9100h
  * auto-tools fixes
  * corpus updates
  * alt-cannadic updates
  * other many fixes; see ChangeLog
* Thu Jan  8 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Mon Dec  1 2008 ro@suse.de
- added baselibs.conf for anthy (needed by uim)
* Fri Jan 11 2008 mfabian@suse.de
- use fdupes only for openSUSE >= 10.3 to make it work for the
  older versions in the openSUSE build service.
* Tue Dec  4 2007 mfabian@suse.de
- remove openldap2 from BuildRequires.
- use fdupes.
* Thu Aug  2 2007 mfabian@suse.de
- update to 9100.
- add ldconfig post scripts.
* Wed Apr 25 2007 mfabian@suse.de
- update to 8813.
* Tue Dec 19 2006 mfabian@suse.de
- update to 8419.
- fix bugzilla #224463.
* Fri Jul 28 2006 mfabian@suse.de
- update to 7917.
  •dictionary of place names added
  •memory leak when the emacs key-map was changed fixed
  •add a dictionary of postal codes
* Tue Feb 28 2006 mfabian@suse.de
- add Provides:     locale(...).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 mfabian@suse.de
- update to 7307.
* Wed Aug  3 2005 mfabian@suse.de
- update to 6801.
- remove Andreas Schwab's cleanup.patch, it is included now.
* Fri May  6 2005 mfabian@suse.de
- update to 6506.
* Sat Apr 23 2005 schwab@suse.de
- Clean up lisp code.
- Move *.so links to devel package.
* Tue Feb  1 2005 mfabian@suse.de
- update to 6131.
* Tue Jan 18 2005 mfabian@suse.de
- fix anthy.el to make 'backspace work when XEmacs is started
  in a terminal "xemacs -nw".
* Tue Dec 28 2004 mfabian@suse.de
- update to 6024.
* Thu Dec 16 2004 mfabian@suse.de
- update to 5924.
* Mon Oct 11 2004 mfabian@suse.de
- make 'anthy-add-word' work with xemacs.
- make 'anthy-add-word-interactive' work for special nouns.
* Mon Sep 20 2004 mfabian@suse.de
- Bugzilla #45561: move .so files to main package. uim needs the
  .so files but uim should not need to have anthy-devel installed
  to work.
- update to 5714:
  - initialize hankaku_kana_table. otherwise segv.
  - depgraph/: update from hmm branch
* Sat Sep  4 2004 mfabian@suse.de
- update to 5704.
* Fri Aug 13 2004 mfabian@suse.de
- update to 5613.
* Tue Feb 24 2004 mfabian@suse.de
- update to 5021.
* Tue Feb 10 2004 mfabian@suse.de
- update to 5008.
- compile and install emacs-lisp file for XEmacs as well.
- don't build as root.
* Mon Aug 25 2003 mfabian@suse.de
- update to 4421.
* Sun Feb 16 2003 mfabian@suse.de
- update to 3814
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
* Mon Aug 12 2002 mfabian@suse.de
- update to 3208
- fix autoconf problem
- anthy-devel should require anthy
- remove extra cannadic sources because they are contained in the
  anthy tarball now.
- add suse-start-anthy.el to make the input-method
  'japanese-anthy automatically available for GNU Emacs as soon
  as anthy is installed.
* Fri Apr  5 2002 mfabian@suse.de
- update to 2427b
- use 'libtoolize --force' and 'autoreconf --force --install'
  to fix build problems
* Wed Apr  3 2002 mfabian@suse.de
- update to version 2307
- update cannadic to 0.94b
- use %%{_libdir}
- add emacs stuff to '# neededforbuild' to be able to compile
  anthy.el
* Sat Sep  8 2001 mfabian@suse.de
- new package: Anthy, version 1800b
